@@ -14,6 +14,10 @@
 #          (1)Output list data
 # v0.1.0 : 2021/04/01 
 #          (1)Output DataFrame
+# v0.1.1 : 2021/08/12
+#           (doppler and range swap in V6 output)
+# v0.1.2 : 2021/09/17
+#           v7 dataframe:'tid' move to front of 'ec0'
 #
 
 import serial
@@ -51,14 +55,15 @@ class Pc3OVH:
 	
 	# provide csv file dataframe
 	# real-time 
-	v6_col_names_rt = ['fN','type','elv','azimuth','range','doppler','snr','sx', 'sy', 'sz']
+	v6_col_names_rt = ['fN','type','elv','azimuth','range','doppler','snr','sx', 'sy', 'sz'] 
 	v7_col_names_rt = ['fN','type','posX','posY','posZ','velX','velY','velZ','accX','accY','accZ','ec0','ec1','ec2','ec3','ec4','ec5','ec6','ec7','ec8','ec9','ec10','ec11','ec12','ec13','ec14','ec15','g','confi','tid']
 	v8_col_names_rt = ['fN','type','targetID']
 	
 	# read from file for trace point clouds
 	fileName = ''
 	v6_col_names = ['time','fN','type','elv','azimuth','range','doppler','snr','sx', 'sy', 'sz']
-	v7_col_names = ['time','fN','type','posX','posY','posZ','velX','velY','velZ','accX','accY','accZ','ec0','ec1','ec2','ec3','ec4','ec5','ec6','ec7','ec8','ec9','ec10','ec11','ec12','ec13','ec14','ec15','g','confi','tid']
+	#v7_col_names = ['time','fN','type','posX','posY','posZ','velX','velY','velZ','accX','accY','accZ','ec0','ec1','ec2','ec3','ec4','ec5','ec6','ec7','ec8','ec9','ec10','ec11','ec12','ec13','ec14','ec15','g','confi','tid']
+	v7_col_names = ['time','fN','type','posX','posY','posZ','velX','velY','velZ','accX','accY','accZ','tid','ec0','ec1','ec2','ec3','ec4','ec5','ec6','ec7','ec8','ec9','ec10','ec11','ec12','ec13','ec14','ec15','g','confi'] #v0.1.2
 	v8_col_names = ['time','fN','type','targetID']
 	sim_startFN = 0
 	sim_stopFN  = 0 
@@ -201,7 +206,7 @@ class Pc3OVH:
 			except:
 				#return (False,v6,v7,v8)
 				#return (False,v6,v7,v8) if (df == None) else self.list2df(False,v6,v7,v8)
-				return self.list2df(False,v6,v7,v8) if (df == 'DataFrame') else (False,v6,v7,v8)
+				return self.list2df(False,v6df,v7df,v8df) if (df == 'DataFrame') else (False,v6,v7,v8)
 				
 			#print(str(ch))
 			if lstate == 'idle':
@@ -345,7 +350,8 @@ class Pc3OVH:
 							sz  = ran * np.sin(elv)
 							sx  = ran * np.cos(elv) * np.sin(azi)
 							sy  = ran * np.cos(elv) * np.cos(azi)
-							v6df.append((self.hdr.frameNumber,'v6',elv,azi,dop,ran,snr,sx,sy,sz))
+							#v6df.append((self.hdr.frameNumber,'v6',elv,azi,dop,ran,snr,sx,sy,sz)) #v0.1.0
+							v6df.append((self.hdr.frameNumber,'v6',elv,azi,ran,dop,snr,sx,sy,sz)) #v0.1.1
 							 
 						else:
 							v6.append((elv,azi,dop,ran,snr))
